@@ -67,7 +67,7 @@ def to_html(entry, *, config: Config, single_indent: int = 2) -> str:
         indent(3, funders_to_html(entry)),
         indent(2, "</span>"),
         indent(2, '<span class="link-list">'),
-        indent(3, doilink_to_html(entry)),
+        indent(3, publisher_version_to_html(entry)),
         indent(3, articlelink_to_html(entry)),
         indent(3, presentationlink_to_html(entry)),
         indent(3, videolink_to_html(entry)),
@@ -388,12 +388,18 @@ def materiallink_to_html(entry):
     return f'<a class="material-link" href="{link}"><img alt="" height="15px" width="15px" src="https://www.sosy-lab.org/research/pub/Icons/www.gif">Supplement</a>'
 
 
-def doilink_to_html(entry):
+def publisher_version_to_html(entry):
+    description = "Link to official version of paper (may be a landing page with more information)"
     try:
         doi = get_doi(entry)
+        return f'<a class="doi-link" href="https://doi.org/{doi}" title="{description}"><img alt="" height="17px" width="17px" src="https://www.sosy-lab.org/research/pub/Icons/doi.svg">Publisher\'s Version</a>'
+    except KeyError:
+        pass
+    try:
+        urn = get_urn(entry)
+        return f'<a class="urn-link" href="https://nbn-resolving.org/process-urn-form?identifier={urn}&verb=REDIRECT" title="{description}">Publisher\'s Version</a>'
     except KeyError:
         return ""
-    return f'<a class="doi-link" href="https://doi.org/{doi}" title="Link to official version of paper (may be a landing page with more information)"><img alt="" height="17px" width="17px" src="https://www.sosy-lab.org/research/pub/Icons/doi.svg">Publisher\'s Version</a>'
 
 
 def doi_to_html(entry):
@@ -438,11 +444,11 @@ def get_doi(entry):
     return doi
 
 
-def get_sha256(entry):
-    try:
-        return entry["sha256"]
-    except KeyError:
-        return ""
+def get_urn(entry):
+    urn = entry["urn"]
+    if not urn:
+        raise KeyError
+    return urn
 
 
 def html_id(entry):
